@@ -22,10 +22,16 @@ void BindButton::setKeyCode(int code)
     this->code = code;
 
     if (code) {
-        Display *display = XOpenDisplay(NULL);
-        char *keysym = XKeysymToString(XKeycodeToKeysym(display, code, 0));
+        const char *keysym = NULL;
+
+        if (code > 0xff) {
+            if (code == 300+68) keysym = "CameraFocus";
+        } else {
+            Display *display = XOpenDisplay(NULL);
+            keysym = XKeysymToString(XKeycodeToKeysym(display, code, 0));
+            XCloseDisplay(display);
+        }
         this->setValueText(keysym ? keysym : QString::number(code));
-        XCloseDisplay(display);
     } else {
         this->setValueText("(unbound)");
     }
@@ -50,6 +56,14 @@ void BindButton::keyPressEvent(QKeyEvent *e)
     }
 }
 
+void BindButton::onCamFocusPressed()
+{
+    if (this->isChecked()) {
+        setKeyCode(300+68);
+        this->setChecked(false);
+    }
+}
+
 void BindButton::contextMenuEvent(QContextMenuEvent*)
 {
     setKeyCode(0);
@@ -67,10 +81,18 @@ void BindButton::onToggled(bool checked)
             if (button != this)
                 button->setChecked(false);
 
+        QDBusConnection::systemBus().connect("", "/org/freedesktop/Hal/devices/platform_cam_focus",
+                                             "org.freedesktop.Hal.Device", "PropertyModified",
+                                             this, SLOT(onCamFocusPressed()));
+
         this->grabKeyboard();
         this->setValueText("???");
         grabZoomKeys(true);
     } else {
+        QDBusConnection::systemBus().disconnect("", "/org/freedesktop/Hal/devices/platform_cam_focus",
+                                                "org.freedesktop.Hal.Device", "PropertyModified",
+                                                this, SLOT(onCamFocusPressed()));
+
         this->releaseKeyboard();
         this->setKeyCode(code);
         grabZoomKeys(false);
