@@ -6,6 +6,8 @@
 #include <QKeyEvent>
 #include <QButtonGroup>
 
+#include <QDBusConnection>
+
 #include <QX11Info>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
@@ -30,6 +32,7 @@ private:
 
 private slots:
     void onToggled(bool checked);
+    void onCamFocusPressed();
 };
 
 #endif // BINDBUTTON_H
