@@ -11,6 +11,7 @@
 #include "launcher.h"
 #include "coredialog.h"
 #include "keysdialog.h"
+#include "accelerometerconfig.h"
 
 class LaunchDialog : public QDialog
 {
@@ -27,6 +28,7 @@ private:
 
     CoreConfig coreConfig;
     KeysConfig keysConfig;
+    AccelerometerConfig accelerometerConfig;
 
     void cleanup();
 
