@@ -1,10 +1,14 @@
 #include "launcher.h"
 
-Launcher::Launcher(QString romFile, CoreConfig *coreConfig, KeysConfig *keysConfig)
+Launcher::Launcher(QString romFile,
+                   CoreConfig *coreConfig,
+                   KeysConfig *keysConfig,
+                   AccelerometerConfig *accelerometerConfig)
 {
     this->romFile = romFile;
     this->coreConfig = coreConfig;
     this->keysConfig = keysConfig;
+    this->accelerometerConfig = accelerometerConfig;
 }
 
 void Launcher::launch()
@@ -17,14 +21,18 @@ void Launcher::launch()
     // Build the list of arguments
     QStringList cmd;
     cmd << Path::emuExe() << quote(romFile) << "--keys" << keysFilePath;
-    if (coreConfig->accelerometer)   cmd << "--accelerometer";
-    if (coreConfig->autopause)       cmd << "--autopause";
+    if (coreConfig->accelerometer)      cmd << "--accelerometer";
+    cmd << "--accelerometer-deadzone" << QString::number(accelerometerConfig->deadzone);
+    cmd << "--accelerometer-pitch"    << QString::number(accelerometerConfig->pitch);
+    cmd << "--accelerometer-roll"     << QString::number(accelerometerConfig->roll);
+    if (accelerometerConfig->calibrate) cmd << "--accelerometer-calibrate";
+    if (coreConfig->autopause)          cmd << "--autopause";
     cmd << "--scale"           << QString::number(coreConfig->scale);
     cmd << "--filter"          << QString::number(coreConfig->filter);
     cmd << "--frameskip-type"  << QString::number(coreConfig->frameskipType);
     cmd << "--frameskip-value" << QString::number(coreConfig->frameskipValue);
-    if (coreConfig->frameskipRandom) cmd << "--random-frameskip";
-    if (coreConfig->soundDisabled)   cmd << "--no-sound";
+    if (coreConfig->frameskipRandom)    cmd << "--random-frameskip";
+    if (coreConfig->soundDisabled)      cmd << "--no-sound";
     cmd << "--sound-buffer"    << QString::number(coreConfig->soundBuffer);
 
     QFile launchFile(launchFilePath);
