@@ -11,11 +11,15 @@
 
 #include "coreconfig.h"
 #include "keysconfig.h"
+#include "accelerometerconfig.h"
 
 class Launcher
 {
 public:
-    Launcher(QString romFile, CoreConfig *coreConfig, KeysConfig *keysConfig);
+    Launcher(QString romFile,
+             CoreConfig *coreConfig,
+             KeysConfig *keysConfig,
+             AccelerometerConfig *accelerometerConfig);
 
     void launch();
 
@@ -24,6 +28,7 @@ private:
 
     CoreConfig *coreConfig;
     KeysConfig *keysConfig;
+    AccelerometerConfig *accelerometerConfig;
 
     static QString quote(QString str);
 };
