@@ -16,6 +16,7 @@
 #include "settingsdialog.h"
 #include "coredialog.h"
 #include "keysdialog.h"
+#include "accelerometerdialog.h"
 
 namespace Ui {
     class MainWindow;
@@ -49,6 +50,7 @@ private slots:
     void openSettingsDialog();
     void openCoreDialog();
     void openKeysDialog();
+    void openAccelerometerDialog();
 };
 
 #endif // MAINWINDOW_H
